summaryrefslogtreecommitdiff
path: root/include/basegfx/polygon/b2dpolypolygontools.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'include/basegfx/polygon/b2dpolypolygontools.hxx')
-rw-r--r--include/basegfx/polygon/b2dpolypolygontools.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/basegfx/polygon/b2dpolypolygontools.hxx b/include/basegfx/polygon/b2dpolypolygontools.hxx
index 90ec04530c52..3f34f8e6f7c5 100644
--- a/include/basegfx/polygon/b2dpolypolygontools.hxx
+++ b/include/basegfx/polygon/b2dpolypolygontools.hxx
@@ -37,7 +37,7 @@ namespace basegfx
class B2DPolyPolygon;
class B2DRange;
- namespace tools
+ namespace utils
{
// B2DPolyPolygon tools
@@ -291,7 +291,7 @@ namespace basegfx
const B2DPolyPolygon& rPolyPolygon,
css::drawing::PolyPolygonBezierCoords& rPolyPolygonBezierCoordsRetval);
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
#endif // INCLUDED_BASEGFX_POLYGON_B2DPOLYPOLYGONTOOLS_HXX